# SR-DICE
is a simple dice simulator for the pen and paper RPG [Shadowrun](https://en.wikipedia.org/wiki/Shadowrun).

## Usage
```
sr-dice [-h] [--hist] [--raw] num_dices

positional arguments:
  num_dices   number of dices to roll

optional arguments:
  -h, --help  show this help message and exit
  --hist      print a histogram of the dice rolls
  --raw       print the raw dice rolls
```

### Bugs
Please report to brolf <at> magheute (dot) net

